summaryrefslogtreecommitdiffstats
path: root/filters/kpresenter/powerpoint/libppt/ustring.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'filters/kpresenter/powerpoint/libppt/ustring.cpp')
-rw-r--r--filters/kpresenter/powerpoint/libppt/ustring.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/filters/kpresenter/powerpoint/libppt/ustring.cpp b/filters/kpresenter/powerpoint/libppt/ustring.cpp
index 23b61d30a..b0a44e562 100644
--- a/filters/kpresenter/powerpoint/libppt/ustring.cpp
+++ b/filters/kpresenter/powerpoint/libppt/ustring.cpp
@@ -216,13 +216,13 @@ UString UString::null;
static char *statBuffer = 0L;
UChar::UChar(const UCharReference &c)
- : uc( c.tqunicode() )
+ : uc( c.unicode() )
{
}
UChar UChar::toLower() const
{
// ### properly support tqunicode tolower
if (uc >= 256 || islower(uc))
return *this;
@@ -644,7 +644,7 @@ bool Libppt::operator<(const UString& s1, const UString& s2)
l++;
}
if (l < lmin)
- return (c1->tqunicode() < c2->tqunicode());
+ return (c1->unicode() < c2->unicode());
return (l1 < l2);
}
@@ -216,13 +216,13 @@ UString UString::null;
UChar UChar::toLower() const
{
- // ### properly support tqunicode tolower
+ // ### properly support unicode tolower
if (uc >= 256 || islower(uc))
return *this;